@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '1.69'; # VERSION
+our $DATE = '2017-01-10'; # DATE
+our $VERSION = '1.70'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1479,54 +1479,6 @@ sub run {
     }
 }
 
-# BEGIN FATPACK CODE: ShellQuote/Any/Tiny.pm
-{
-    no strict 'refs';
-    $main::fatpacked{"ShellQuote/Any/Tiny.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'SHELLQUOTE_ANY_TINY';
-#package ShellQuote::Any::Tiny;
-#
-#our $DATE = '2016-12-27';
-#our $VERSION = '0.003';
-#
-#use strict;
-#use warnings;
-#
-#use Exporter qw(import);
-#our @EXPORT_OK = qw(shell_quote);
-#
-#sub shell_quote {
-#    my $arg = shift;
-#
-#    if ($^O eq 'MSWin32') {
-#        if ($arg =~ /\A\w+\z/) {
-#            return $arg;
-#        }
-#        $arg =~ s/([\\"])/\\$1/g;
-#        return qq("$arg");
-#    } else {
-#        if ($arg =~ /\A\w+\z/) {
-#            return $arg;
-#        }
-#        $arg =~ s/'/'"'"'/g;
-#        return "'$arg'";
-#    }
-#}
-#
-#1;
-#
-#__END__
-#
-SHELLQUOTE_ANY_TINY
-
-    $main::fatpacked{$_} =~ s/^\#//mg for ('ShellQuote/Any/Tiny.pm');
-    my $class = 'FatPacked::'.(0+\%main::fatpacked);
-    unless (defined &{"${class}::INC"}) { if ($] < 5.008) { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { return sub { return 0 unless length $fat; $fat =~ s/^([^\n]*\n?)//; $_ = $1; return 1; }; } return; }; } else { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { open my $fh, '<', \$fat or die "FatPacker error loading $_[1] (could be a perl installation issue?)"; return $fh; } return; }; } }
-    my $hook = bless(\%main::fatpacked, $class);
-    push @INC, $hook unless grep {ref($_) && "$_" eq "$hook"} @INC;
-}
-# END OF FATPACK CODE
-
-
 1;
 # ABSTRACT: Base class for Perinci::CmdLine{::Classic,::Lite}
 
@@ -1542,7 +1494,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.69 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2017-01-04.
+This document describes version 1.70 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2017-01-10.
 
 =head1 DESCRIPTION
 
